@@ -1,4 +1,4 @@
-mkExcelCsd=function(seerSet,tsdn,biny="[1973,2015)",bina="(0,126]",outDir="~/Results",outName=NULL,flip=FALSE) {
+mkExcelCsd=function(seerSet,tsdn,biny="[1973,2016)",bina="(0,126]",outDir="~/Results",outName=NULL,flip=FALSE) {
   if (length(tsdn)>1) {
     cat("collapsing brks vector to a tsdn string\n") 
     tsdn=paste0("b",paste(tsdn,collapse="_"))
@@ -8,8 +8,10 @@ mkExcelCsd=function(seerSet,tsdn,biny="[1973,2015)",bina="(0,126]",outDir="~/Res
   if (is.null(seerSet$L)) stop("seerSet L field is empty. Please run csd on your seerSet object to fill it!") else 
     L=seerSet$L[[tsdn]]
   if (!dir.exists(outDir)) dir.create(outDir,recursive=T)
+  hs1=createStyle(fgFill="#DCE6F1",halign="CENTER",textDecoration="bold")
   unlink(f<-paste0(outDir,"/",ifelse(is.null(outName),paste0(seerSet$bfn,tsdn,yn,an),outName),ifelse(flip,"Flipped",""),".xlsx"))
-  wb <- loadWorkbook(f,create=T) 
+  # wb <- loadWorkbook(f,create=T)
+  wb <- createWorkbook() 
   OL=NULL
   # intvs=names(L[[L$trtS[1]]][["Obs"]]) 
   intvs=names(L[[L$trtS[1]]][[biny]][[bina]][["Obs"]]) 
@@ -18,7 +20,9 @@ mkExcelCsd=function(seerSet,tsdn,biny="[1973,2015)",bina="(0,126]",outDir="~/Res
   if (flip) sheetS=seerSet$secondS
   for (icanc in sheetS) {
     #    icanc="prostate"
-    createSheet(wb, name = icanc)
+    # createSheet(wb, name = icanc)
+    addWorksheet(wb,icanc)
+    
     M=NULL
     for (R in L$trtS) {
       D=NULL
@@ -52,15 +56,19 @@ mkExcelCsd=function(seerSet,tsdn,biny="[1973,2015)",bina="(0,126]",outDir="~/Res
       M=cbind(M,D)
     } #rad
     #     writeWorksheet(wb, data.frame("second cancer"=picks,M), sheet = icanc,rownames=1)
-    if (flip) writeWorksheet(wb, cbind("1st cancer"=L$firstS,M), sheet = icanc,rownames=1) else
-      writeWorksheet(wb, cbind("2nd cancer"=seerSet$secondS,M), sheet = icanc,rownames=1)
+    # if (flip) writeWorksheet(wb, cbind("1st cancer"=L$firstS,M), sheet = icanc,rownames=1) else
+    #   writeWorksheet(wb, cbind("2nd cancer"=seerSet$secondS,M), sheet = icanc,rownames=1)
+    if (flip) writeData(wb, icanc,cbind("1st cancer"=L$firstS,M), headerStyle = hs1) else
+      writeData(wb, icanc, cbind("2nd cancer"=seerSet$secondS,M), headerStyle = hs1)
     OL[[icanc]]=M
-    setColumnWidth(wb,sheet = icanc, column = 1, width = 2500)
-    for (j in 2:(dim(M)[2]+1)) setColumnWidth(wb,sheet = icanc, column = j, width = 4700)
+    setColWidths(wb,icanc, cols = 1:(dim(M)[2]+1), widths = "auto")
+    # for (j in 2:(dim(M)[2]+1)) setColumnWidth(wb,sheet = icanc, column = j, width = 4700)
     #     for (j in 1:(dim(M)[2]+1)) setColumnWidth(wb,sheet = icanc, column = j, width = 5600)
-    createFreezePane(wb,sheet = icanc,2,2) 
+    # createFreezePane(wb,sheet = icanc,2,2) 
+    freezePane(wb,icanc,firstRow = TRUE, firstCol = TRUE) 
   } #icanc
-  saveWorkbook(wb)
+  # saveWorkbook(wb)
+  saveWorkbook(wb,file=f,overwrite = TRUE)
   cat("Workbook was written to",f,"\n")
   invisible(OL)
 }
